==> fs_moodle5-00-03_1-9-19_20131004.zip: moodle/course/editsection.php <==
<?php // $Id$
      // Edit the introduction of a section

    require_once("../config.php");
    require_once("lib.php");

    $id = required_param('id',PARAM_INT);    // Week ID

    if (! $section = get_record("course_sections", "id", $id)) {
        error("Course section is incorrect");
    }

    if (! $course = get_record("course", "id", $section->course)) {
        error("Could not find the course!");
    }

    require_login($course->id);

    require_capability('moodle/course:update', get_context_instance(CONTEXT_COURSE, $course->id));

/// If data submitted, then process and store.

    if ($form = data_submitted() and confirm_sesskey()) {

        $timenow = time();

        if (! set_field("course_sections", "summary", $form->summary, "id", $section->id)) {
            error("Could not update the summary!");
        }

        add_to_log($course->id, "course", "editsection", "editsection.php?id=$section->id", "$section->section");

// (Shirai185): モジュールの追加／更新時の「保存してコースに戻る」時と，画面下のジャンプボタンを押してモジュールからコースに戻る際に，ページトップではなくモジュールの属するセクションへジャンプする機能の追加 (2010/04/08)
// (Shirai185): ここからコメントアウト (Thanks > h.okumura)
//      redirect("view.php?id=$course->id");
// (Shirai185): ここから追加
        if (fs_function_enable('FS_DISABLE_BACKTOSECTION') and (!empty($section->section))) $secstr = '#section-'.$section->section;
            else $secstr = '';
        redirect("view.php?id=$course->id".$secstr);
// (Shirai185): ここまで追加
        exit;
    }

/// Otherwise fill and print the form.

    if (empty($form)) {
        $form = $section;
    } else {
        $form = stripslashes_safe($form);
    }

    // !! no db access using data from $form beyond this point !!

    $usehtmleditor = can_use_html_editor();

/// Inelegant hack for bug 3408
    if ($course->format == 'site') {
        $sectionname  = get_string('site');
        $stredit      = get_string('edit', '', " $sectionname");
        $strsummaryof = get_string('summaryof', '', " $sectionname");
    } else {
        $sectionname  = get_section_name($course->format);
        $stredit      = get_string('edit', '', " $sectionname $section->section");
        $strsummaryof = get_string('summaryof', '', " $sectionname $section->section");
    }

    print_header_simple($stredit, '', build_navigation(array(array('name' => $stredit, 'link' => null, 'type' => 'misc'))), 'theform.summary' );

    print_heading($strsummaryof);
    print_simple_box_start('center');
    include('editsection.html');
    print_simple_box_end();

    if ($usehtmleditor) {
        use_html_editor("summary");
    }
    print_footer($course);

?>

==> fs_moodle5-00-05_1-8-14_20140504.zip: moodle/course/editsection.php <==
<?php // $Id: editsection.php,v 1.24.4.2 2009/02/05 13:31:42 stronk7 Exp $
      // Edit the introduction of a section

    require_once("../config.php");
    require_once("lib.php");

    $id = required_param('id',PARAM_INT);    // Week ID

    if (! $section = get_record("course_sections", "id", $id)) {
        error("Course section is incorrect");
    }

    if (! $course = get_record("course", "id", $section->course)) {
        error("Could not find the course!");
    }

    require_login($course->id);

    require_capability('moodle/course:update', get_context_instance(CONTEXT_COURSE, $course->id));

/// If data submitted, then process and store.

    if ($form = data_submitted() and confirm_sesskey()) {

        $timenow = time();

        if (! set_field("course_sections", "summary", $form->summary, "id", $section->id)) {
            error("Could not update the summary!");
        }

        add_to_log($course->id, "course", "editsection", "editsection.php?id=$section->id", "$section->section");
        
// (Shirai185): モジュールの追加／更新時の「保存してコースに戻る」時と，画面下のジャンプボタンを押してモジュールからコースに戻る際に，ページトップではなくモジュールの属するセクションへジャンプする機能の追加 (2010/04/08)
// (Shirai185): ここからコメントアウト (Thanks > h.okumura)
//      redirect("view.php?id=$course->id");
// (Shirai185): ここから追加
        if (fs_function_enable('FS_DISABLE_BACKTOSECTION') and (!empty($section->section))) $secstr = '#section-'.$section->section;
            else $secstr = '';
        redirect("view.php?id=$course->id".$secstr);
// (Shirai185): ここまで追加
        exit;
    }

/// Otherwise fill and print the form.

    if (empty($form)) {
        $form = $section;
    } else {
        $form = stripslashes_safe($form);
    }

    // !! no db access using data from $form beyond this point !!

    $usehtmleditor = can_use_html_editor();

/// Inelegant hack for bug 3408
    if ($course->format == 'site') {
        $sectionname  = get_string('site');
        $stredit      = get_string('edit', '', " $sectionname");
        $strsummaryof = get_string('summaryof', '', " $sectionname");
    } else {
        $sectionname  = get_section_name($course->format);
        $stredit      = get_string('edit', '', " $sectionname $section->section");
        $strsummaryof = get_string('summaryof', '', " $sectionname $form->section");
    }

    print_header_simple($stredit, '', $stredit, 'theform.summary' );

    print_heading($strsummaryof);
    print_simple_box_start('center');
    include('editsection.html');
    print_simple_box_end();

    if ($usehtmleditor) { 
        use_html_editor("summary");
    }
    print_footer($course);

?>
